@@ -2,6 +2,9 @@ class SpotifyPlaylistManager:
     """
     Handles Spotify playlists callbacks. To implement you own callbacks,
     inherit from this class.
+
+    Exceptions raised in your callback handlers will be displayed on the
+    standard error output (stderr).
     """
 
     def __init__(self):
@@ -11,10 +14,9 @@ class SpotifyPlaylistManager:
         """
         Listen to modifications events on a playlist.
         """
-        playlist.add_tracks_added_callback(self.tracks_added, self, userdata)
-        playlist.add_tracks_moved_callback(self.tracks_moved, self, userdata)
-        playlist.add_tracks_removed_callback(self.tracks_removed, self,
-            userdata)
+        playlist.add_tracks_added_callback(self.tracks_added, userdata)
+        playlist.add_tracks_moved_callback(self.tracks_moved, userdata)
+        playlist.add_tracks_removed_callback(self.tracks_removed, userdata)
 
     def unwatch(self, playlist, userdata=None):
         """
